@@ -49,6 +49,7 @@ class CfnCluster(
         node_type: builtins.str,
         replication_factor: jsii.Number,
         availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
+        cluster_endpoint_encryption_type: typing.Optional[builtins.str] = None,
         cluster_name: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         notification_topic_arn: typing.Optional[builtins.str] = None,
@@ -67,6 +68,7 @@ class CfnCluster(
         :param node_type: ``AWS::DAX::Cluster.NodeType``.
         :param replication_factor: ``AWS::DAX::Cluster.ReplicationFactor``.
         :param availability_zones: ``AWS::DAX::Cluster.AvailabilityZones``.
+        :param cluster_endpoint_encryption_type: ``AWS::DAX::Cluster.ClusterEndpointEncryptionType``.
         :param cluster_name: ``AWS::DAX::Cluster.ClusterName``.
         :param description: ``AWS::DAX::Cluster.Description``.
         :param notification_topic_arn: ``AWS::DAX::Cluster.NotificationTopicARN``.
@@ -82,6 +84,7 @@ class CfnCluster(
             node_type=node_type,
             replication_factor=replication_factor,
             availability_zones=availability_zones,
+            cluster_endpoint_encryption_type=cluster_endpoint_encryption_type,
             cluster_name=cluster_name,
             description=description,
             notification_topic_arn=notification_topic_arn,
@@ -135,6 +138,14 @@ class CfnCluster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrClusterDiscoveryEndpoint"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrClusterDiscoveryEndpointUrl")
+    def attr_cluster_discovery_endpoint_url(self) -> builtins.str:
+        '''
+        :cloudformationAttribute: ClusterDiscoveryEndpointURL
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrClusterDiscoveryEndpointUrl"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
@@ -204,6 +215,22 @@ class CfnCluster(
     ) -> None:
         jsii.set(self, "availabilityZones", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="clusterEndpointEncryptionType")
+    def cluster_endpoint_encryption_type(self) -> typing.Optional[builtins.str]:
+        '''``AWS::DAX::Cluster.ClusterEndpointEncryptionType``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clusterendpointencryptiontype
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterEndpointEncryptionType"))
+
+    @cluster_endpoint_encryption_type.setter
+    def cluster_endpoint_encryption_type(
+        self,
+        value: typing.Optional[builtins.str],
+    ) -> None:
+        jsii.set(self, "clusterEndpointEncryptionType", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="clusterName")
     def cluster_name(self) -> typing.Optional[builtins.str]:
@@ -370,6 +397,7 @@ class CfnCluster(
         "node_type": "nodeType",
         "replication_factor": "replicationFactor",
         "availability_zones": "availabilityZones",
+        "cluster_endpoint_encryption_type": "clusterEndpointEncryptionType",
         "cluster_name": "clusterName",
         "description": "description",
         "notification_topic_arn": "notificationTopicArn",
@@ -389,6 +417,7 @@ class CfnClusterProps:
         node_type: builtins.str,
         replication_factor: jsii.Number,
         availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
+        cluster_endpoint_encryption_type: typing.Optional[builtins.str] = None,
         cluster_name: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         notification_topic_arn: typing.Optional[builtins.str] = None,
@@ -405,6 +434,7 @@ class CfnClusterProps:
         :param node_type: ``AWS::DAX::Cluster.NodeType``.
         :param replication_factor: ``AWS::DAX::Cluster.ReplicationFactor``.
         :param availability_zones: ``AWS::DAX::Cluster.AvailabilityZones``.
+        :param cluster_endpoint_encryption_type: ``AWS::DAX::Cluster.ClusterEndpointEncryptionType``.
         :param cluster_name: ``AWS::DAX::Cluster.ClusterName``.
         :param description: ``AWS::DAX::Cluster.Description``.
         :param notification_topic_arn: ``AWS::DAX::Cluster.NotificationTopicARN``.
@@ -424,6 +454,8 @@ class CfnClusterProps:
         }
         if availability_zones is not None:
             self._values["availability_zones"] = availability_zones
+        if cluster_endpoint_encryption_type is not None:
+            self._values["cluster_endpoint_encryption_type"] = cluster_endpoint_encryption_type
         if cluster_name is not None:
             self._values["cluster_name"] = cluster_name
         if description is not None:
@@ -482,6 +514,15 @@ class CfnClusterProps:
         result = self._values.get("availability_zones")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def cluster_endpoint_encryption_type(self) -> typing.Optional[builtins.str]:
+        '''``AWS::DAX::Cluster.ClusterEndpointEncryptionType``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clusterendpointencryptiontype
+        '''
+        result = self._values.get("cluster_endpoint_encryption_type")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def cluster_name(self) -> typing.Optional[builtins.str]:
         '''``AWS::DAX::Cluster.ClusterName``.
